import logging

# database configuration
DB_USER = "MySqlUserName"
DB_PASS = "MySqlPassword"
DB_HOST = "localhost"
DB_PORT = "3306" # Normally 3306
DB_NAME = "BoSignals" # if you have more than one station, use BoSignals_9999 where 9999 is your BO_STATION ID

# Blitzortung configuration
BO_USER = "BlitzortungUserName"
BO_PASS = "BlitzortungPassword"
BO_STATION = "9999" # my Blitzortung station ID
BO_REGION = [1] # comma separated list of regions the BO_STATION belongs to, maximum [1, 2, 3, 4, 5]
                # region 1 is Europe
                # region 2 is Oceania
                # region 3 is North America
                # region 4 is Asia
                # region 5 is South America

# destination path to which the images are generated and source path for the FTP transfer to the web-server
FTP_LOCAL_PATH = "/var/www/html/Blitzortung" # if you have more than one station, use Blitzortung_9999 where 9999 is your BO_STATION ID

# destination path for the book keeping files of boGetSignalsFromBlitzortung.py, boGetStrokesFromBlitzortung.py and boGenerateImages.py
# please avoid using the following file names in cron or any other application:
# BOOK_KEEPING_PATH/boGetSignalsFromBlitzortung.txt
# BOOK_KEEPING_PATH/boGetStrokesFromBlitzortung.txt
# BOOK_KEEPING_PATH/boGenerateImages.txt
BOOK_KEEPING_PATH = "/home/public/Blitzortung" # if you have more than one station, use Blitzortung_9999 where 9999 is your BO_STATION ID

# number of threads for the image generation
# Recommendation: maximum use the number of cores of your CPU; check the effect with 'top'
# If the swap memory is constantly used, reduce the number of threads. Many cores won't speed up if the system is out of memory.
NUM_IMAGE_THREADS = 1

# list of immages to be generated
# for help start ./boPng.php --help
CHANNEL_NUMBER = [0, 1, 2, 3] # channel 0..3 for System Blue and System Red, chanel 4..5 for System Red only; you may want to keep this setting similar to CHANNEL_NUMBER in boConfig.php
IMAGES = [
    "-i7 -t1d", # map channel strokes on MAP, all channels, limited to the last day, System Blue and System Red
    "-i10 -n1000", # map channel strokes on MAP_WORLD, all channels, 1000 most distant, System Blue and System Red
    "-i12", # strokes(channel) and locating ratio 1y, System Blue and System Red
    "-i8", # strokes(channel) and locating ratio 14d, System Blue and System Red
    "-i9", # strokes(channel) and locating ratio 24h, System Blue and System Red
    "-i1 -t1h", # strokes(channel)/num(strokes), limited to the last hour, System Blue and System Red
    "-i2 -t1h", # strokes(channel)/signals(channel), limited to the last hour, System Blue and System Red
    "-i3 -t1h", # signals(channel)-strokes(channel), limited to the last hour, System Blue and System Red
    "-i4 -t1h", # strokes(channel), limited to the last hour, System Blue and System Red
    "-i1 -t1d", # strokes(channel)/num(strokes), limited to the last day, System Blue and System Red
    "-i2 -t1d", # strokes(channel)/signals(channel), limited to the last day, System Blue and System Red
    "-i3 -t1d", # signals(channel)-strokes(channel), limited to the last day, System Blue and System Red
    "-i4 -t1d", # strokes(channel), limited to the last day, System Blue and System Red
    "-i1 -t1w", # strokes(channel)/num(strokes), limited to the last week, System Blue and System Red
    "-i2 -t1w", # strokes(channel)/signals(channel), limited to the last week, System Blue and System Red
    "-i3 -t1w", # signals(channel)-strokes(channel), limited to the last week, System Blue and System Red
    "-i4 -t1w", # strokes(channel), limited to the last week, System Blue and System Red
    "-i1", # strokes(channel)/num(strokes), since the start of the recording, System Blue and System Red
    "-i2", # strokes(channel)/signals(channel), since the start of the recording, System Blue and System Red
    "-i3", # signals(channel)-strokes(channel), since the start of the recording, System Blue and System Red
    "-i4", # strokes(channel), since the start of the recording, System Blue and System Red
    "-i6 -t1d", # strokes per distance per channel, limited to the last day, System Blue and System Red
    "-i6", # strokes per distance per channel, since the start of the recording, System Blue and System Red
]

for c in CHANNEL_NUMBER:
    IMAGES.append("-i7 -t1d -c{} -w320 -h205".format(c)) # map channel strokes on MAP, channel c, limited to the last day, System Blue a/o System Red
    IMAGES.append("-i5 -c{}".format(c)) # signals(channel), strokes(channel)/signals(channel), 24h, channel c, System Blue a/o System Red

# configuration settings for boPng.py
IMG11_START_DATE_TIME = None               # date time in the format "YYYY.MM.DD hh:mm" UTC or None
IMG11_END_DATE_TIME   = None               # date time in the format "YYYY.MM.DD hh:mm" UTC or None

# destination path for the logger files of boGetSignalsFromBlitzortung.py, boGetStrokesFromBlitzortung.py and boUdpParser.py
# please avoid using the following file names in cron or any other application:
# LOGGING_PATH/boGetSignalsFromBlitzortung.log
# LOGGING_PATH/boGetStrokesFromBlitzortung.log
# LOGGING_PATH/boUdpParser.log
LOGGING_PATH = "/var/log"

# logger configuration
#LOGLEVEL = logging.CRITICAL
LOGLEVEL = logging.ERROR
#LOGLEVEL = logging.WARNING
#LOGLEVEL = logging.INFO
#LOGLEVEL = logging.DEBUG
