<?php
define("TIME_STEP", 10 * 60); // the Blitzortung server updates the signal and stroke data every 10 minutes

// This function returns a time in seconds since 1970.01.01 00:00:00 UTC.
// The time is aligned to the $step width.
// in:
//  $step: time in seconds to which the time is rounded, default TIME_STEP
// out:
//  start-time in seconds since 1970.01.01 00:00:00 UTC
function getStartTime($step) {
    $time = gmmktime(); // UTC now
    $time = floor($time / $step) * $step; // align to the previous step
    return($time);
}

function UtcToLocalTimeString($time, $format) {
    $dt = new DateTime();
    $dt->setTimeStamp($time);
    $dt->setTimeZone(new DateTimeZone(TZ));
    return $dt->format($format);
}

// This function returns an array with 'start_ns' in nano seconds and 'timeString' with the start/end time information
// in:
//  $seconds: time in seconds back from now
//  $step: time in seconds, default TIME_STEP
//  $endTime: end time in seconds
// out:
//  array["start_ns", "end_ns", "timeString"]
function getStartNsAndTimeString($seconds = null, $step = TIME_STEP, $endTime = null) {
    if (is_null($endTime)) {
        $endTime = getStartTime($step);
    }
    $end_ns = "$endTime"."000000000";
    $timeString = UtcToLocalTimeString($endTime, "Y-m-d H:i");
    if (is_null($seconds) or (0 == $seconds)) {
        $start_ns = null;
    } else {
        $startTime = $endTime - $seconds;
        $start_ns = "$startTime"."000000000";
        $timeString = UtcToLocalTimeString($startTime, "Y-m-d H:i") . " - " . $timeString;
    }
    return ["start_ns" => $start_ns, "end_ns" => $end_ns, "timeString" => $timeString];
}

function getCommandLine($skipProgram = false) {
    global $argc, $argv;
    $commadLine = "";
    if ($skipProgram) {
        $start = 1;
    } else {
        $start = 0;
    }
    for ($i=$start; $i<$argc; $i++) {
        $commadLine .= $argv[$i];
        $commadLine .= " ";
    }
    $commadLine = rtrim($commadLine);
    return ($commadLine);
}
?>
